import distutils, distutils.util
import os
import setuptools

import lokrez, lokrez.version

if os.name == "nt":
    import cx_Freeze

author = "Lertsenem"
mail = "lertsenem@lertsenem.com"

# Load README for long_description
with open("README.adoc", "r") as fh:
    long_description = fh.read()

if os.name == "nt":
    enterprise = "Smash@Lyon"
    arch = distutils.util.get_platform().split("-")[-1]
    build_exe_options = {
            "packages": ["os"],
            "include_msvcr": True,
            }
    bdist_msi_options = {
            "upgrade_code": "{123456789-1337-8483-ABCD-DEADBEEFCAFE}",
            "add_to_path": True,
            "initial_target_dir": r"[LocalAppDataFolder]\{}\{}" \
                    .format(
                        enterprise,
                        lokrez.version.NAME,
                        ),
            }

    options = {
        "build_exe": build_exe_options,
        "bdist_msi": bdist_msi_options,
        },

    base = None

    executables = [
            cx_Freeze.Executable(
                script = "__init__.py",
                targetName = "{}.exe".format(lokrez.version.NAME),
                base = base,
                )
            ],

    setup = cx_Freeze.setup

else:
    options = None
    executables = None
    setup = setuptools.setup

setup(
        name = lokrez.version.NAME,
        version = lokrez.__version__,
        author = author,
        author_email = mail,
        description = "A smash.gg-connected local results generator for SSBU",
        long_description = long_description,
        long_description_content_type = "text/asciidoc",
        url = "https://git.lertsenem.com/lertsenem/ssbu_lokrez",
        packages = ["lokrez"],
        install_requires = [
            "jinja2",
            "requests",
            ],
        license = "MIT",
        classifiers = [
            "Programming Language :: Python :: 3",
            "License :: OSI Approved :: MIT License",
            "Operating System :: OS Independent",
            "Intended Audience :: Smash Bros Ultimate Players",
            ],
        python_requires = ">=3.5",
        keywords = "smash ultimate local results esport smashgg",
#        data_files = ("res", ["res/playerskinsdb.json"])
        package_data = {
            "lokrez": [
                "data/*.json",
                "queries/*.gql",
                "templates/*/*.j2",
                ],
            },
        entry_points = {
            "console_scripts": [
                "lokrez = lokrez:main",
                ],
            },
        options = options,
        executables = executables,
        )
